/*   JavaScript code for Konfabulator widgets.
 *   Copyright (C) 2005 Sarah Tuohy <sjt2005@gmail.com>
 *   Checks for Gallery updates for a particular widget.
 *
 *   This work is licensed under the Creative Commons Attribution-NonCommercial-
 *   ShareAlike License. To view a copy of this license, visit
 *   http://creativecommons.org/licenses/by-nc-sa/2.5/ or send a letter to
 *   Creative Commons, 543 Howard Street, 5th Floor, San Francisco, California,
 *   94105, USA.
 *
 *   A copy of the license was also distributed with this widget.
 */

 //////////////////////////////////////////////////////////////////////////////////
 // FileName: checkForUpdates.js
 // Description: for a particular widget id, checks for a newer version of a widget
 //////////////////////////////////////////////////////////////////////////////////

var checkForUpdateURL = new URL();
var checkWidgetID;
var checkVersionNumber;
var checkDisplayOkMsg;

function checkForUpdates(myWidgetID, myVersionNumber, displayOkMsg) {
    checkWidgetID=myWidgetID;
    checkVersionNumber=myVersionNumber;
    checkDisplayOkMsg=displayOkMsg;

    var theURL="";

    if ( myWidgetID <= 0 )
        theURL = "http://www.orbona.com/versionfiles/version" + myWidgetID + ".txt"
    else {
        usingGallery = true;
        theURL  = "http://www.widgetgallery.com/view.php?widget=" + myWidgetID
    }

    checkForUpdateURL.location= theURL;
    checkForUpdateURL.fetchAsync(processCheckForUpdates);

}

function processCheckForUpdates(processURL) {
    var title="";
    var siteVersion="";
    var downloadSiteName = "";
    var urlData = checkForUpdateURL.result;
    var badResponse = false;

    if ( processURL.response != "200" )
        badResponse = true;
    else {
        if (checkWidgetID <= 0) {
            var lines = urlData.split('|');

            title = lines[0];
            siteVersion=lines[1];
            theGalleryURL=lines[2];
            downloadSiteName=lines[3];
         }
         else {
             downloadSiteName = "the Widget Gallery";

             var regexTitle = /<div class=\"item-title\" align=\"center\">([.\s\S]*?)<\/div>/i;
             var regexVerString = /<div align=\"right\">Version (\d+.\d+(.\d+)?) - /i;

             var titleResult = regexTitle.exec(urlData);
             title = (titleResult!=null) ? titleResult[1] : "";

             var versionString = regexVerString.exec( urlData );
             siteVersion = (versionString!=null) ? versionString[1] : "";
         }
    }

    if (badResponse)
        alert ( "Unable to check for a newer version at this time.  Please try again later." );
    else {
        if (siteVersion=="")
            alert ( "Error retrieving version number.  Please try again later.");
        else {
            var currentIsNewest = true;

            if ( siteVersion != checkVersionNumber ) {

                var siteVersionPieces = siteVersion.split('.');
                var myVersionPieces = checkVersionNumber.split('.');

                //i'm expecting version number to yield an array of size 2 or 3.
                //to make things easier, let's populate the third
                if (siteVersionPieces.length < 3)
                    siteVersionPieces[2]="0";

                if (myVersionPieces.length < 3)
                    myVersionPieces[2]="0";

                if (parseInt(myVersionPieces[0]) < parseInt(siteVersionPieces[0]))
                    currentIsNewest = false;
                else if (parseInt(myVersionPieces[0]) == parseInt(siteVersionPieces[0])) {
                    //compare second parts
                    if (parseInt(myVersionPieces[1]) < parseInt(siteVersionPieces[1]))
                        currentIsNewest = false;
                    else if (parseInt(myVersionPieces[1]) == parseInt(siteVersionPieces[1])) {
                        //compare second parts
                        if (parseInt(myVersionPieces[2]) < parseInt(siteVersionPieces[2]))
                            currentIsNewest = false;
                        //else --> >= , so we have the newest
                    }
                }
                //else --> currentIsNewest
                if (!currentIsNewest) {
                    var doUpdate = alert ("There is a newer version of \"" + title + "\" available. Your version is " + checkVersionNumber + ".  The newest version is " + siteVersion + "\n\nWould you like to visit " + downloadSiteName + " to download the newest version?", "Yes", "No");

                    if ( doUpdate == 1 )
                        openURL( theGalleryURL );
                }

            } //versions are diff

            if (checkDisplayOkMsg && currentIsNewest)
                alert ( "You are running the most recent version of \"" + title + "\": " + checkVersionNumber );

        } //site version not blank
    } //good response from url
}