/*   JavaScript code for Konfabulator Widgets.
 *   Copyright (C) 2005 Sarah Tuohy <sjt2005@gmail.com>
 *   Strips unseemly HTML character codes from a string.  Useful when scraping
 *   web pages.
 *
 *   This work is licensed under the Creative Commons Attribution-NonCommercial-
 *   ShareAlike License. To view a copy of this license, visit
 *   http://creativecommons.org/licenses/by-nc-sa/2.5/ or send a letter to
 *   Creative Commons, 543 Howard Street, 5th Floor, San Francisco, California,
 *   94105, USA.
 *
 *   A copy of the license was also distributed with this widget.
 */

 /////////////////////////////////////////////////////////////////////////////////
 // FileName: cleanHTML.js
 // Description: to strip HTML character codes from a string.  "initSpecialArrays"
 //              *must* be called first, then "cleanHTML" can be called on a
 //              string. Usually, "initSpecialArrays" is called from the onLoad
 //              event/trigger of a widget.
 /////////////////////////////////////////////////////////////////////////////////

    var specialArray = new Array();
    var replacementArray = new Array();
    var specialArraysInitted = false;

function initSpecialArrays(){
    var idx=0;

    specialArray[idx] = /&lsquo;/gi;      replacementArray[idx++] = "'";                 //  left single quote
    specialArray[idx] = /&rsquo;/gi;      replacementArray[idx++] = "'";                 //  right single quote
    specialArray[idx] = /&sbquo;/gi;      replacementArray[idx++] = "'";                 //  single low-9 quote
    specialArray[idx] = /&ldquo;/gi;      replacementArray[idx++] = "\"";                //  left double quote
    specialArray[idx] = /&rdquo;/gi;      replacementArray[idx++] = "\"";                //  right double quote
    specialArray[idx] = /&bdquo;/gi;      replacementArray[idx++] = "\"";                //  double low-9 quote
    specialArray[idx] = /&dagger;/gi;     replacementArray[idx++] = "<dagger>";          //  dagger
    specialArray[idx] = /&Dagger;/gi;     replacementArray[idx++] = "<double dagger>";   //  double dagger
    specialArray[idx] = /&permil;/gi;     replacementArray[idx++] = "<per million>";     //  per mill sign
    specialArray[idx] = /&lsaquo;/gi;     replacementArray[idx++] = "'";                 //  single left-pointing angle quote
    specialArray[idx] = /&rsaquo;/gi;     replacementArray[idx++] = "'";                 //  single right-pointing angle quote
    specialArray[idx] = /&spades;/gi;     replacementArray[idx++] = "<spades>";          // ? black spade suit
    specialArray[idx] = /&clubs;/gi;      replacementArray[idx++] = "<clubs>";           // ? black club suit
    specialArray[idx] = /&hearts;/gi;     replacementArray[idx++] = "<hearts>";          // ? black heart suit
    specialArray[idx] = /&diams;/gi;      replacementArray[idx++] = "<diamonds>";        // ? black diamond suit
    specialArray[idx] = /&oline;/gi;      replacementArray[idx++] = "<overline>";        // ? overline, = spacing overscore
    specialArray[idx] = /&larr;/gi;       replacementArray[idx++] = "<left arrow>";      // ? leftward arrow
    specialArray[idx] = /&uarr;/gi;       replacementArray[idx++] = "<up arrow>";        // ? upward arrow
    specialArray[idx] = /&rarr;/gi;       replacementArray[idx++] = "<right arrow>";     // ? rightward arrow
    specialArray[idx] = /&darr;/gi;       replacementArray[idx++] = "<down arrow>";      // ? downward arrow
    specialArray[idx] = /&trade;/gi;      replacementArray[idx++] = " TM";               //  trademark sign
    specialArray[idx] = /&#09;/gi;        replacementArray[idx++] = "";                  // horizontal tab
    specialArray[idx] = /&#10;/gi;        replacementArray[idx++] = "";                  // line feed
    specialArray[idx] = /&#32;/gi;        replacementArray[idx++] = "";                  // space
    specialArray[idx] = /&#33;/gi;        replacementArray[idx++] = "!";                 // ! exclamation mark
    specialArray[idx] = /&quot;/gi;       replacementArray[idx++] = "\"";                // " double quotation mark
    specialArray[idx] = /&#34;/gi;        replacementArray[idx++] = "\"";                // " double quotation mark
    specialArray[idx] = /&#35;/gi;        replacementArray[idx++] = "#";                 // # number sign
    specialArray[idx] = /&#36;/gi;        replacementArray[idx++] = "$";                 // $ dollar sign
    specialArray[idx] = /&#37;/gi;        replacementArray[idx++] = "%";                 // % percent sign
    specialArray[idx] = /&amp;/gi;        replacementArray[idx++] = "&";                 // & ampersand
    specialArray[idx] = /&#38;/gi;        replacementArray[idx++] = "&";                 // & ampersand
    specialArray[idx] = /&#39;/gi;        replacementArray[idx++] = "'";                 // ' apostrophe
    specialArray[idx] = /&#40;/gi;        replacementArray[idx++] = "(";                 // ( left parenthesis
    specialArray[idx] = /&#41;/gi;        replacementArray[idx++] = ")";                 // ) right parenthesis
    specialArray[idx] = /&#42;/gi;        replacementArray[idx++] = "*";                 // * asterisk
    specialArray[idx] = /&#43;/gi;        replacementArray[idx++] = "+";                 // + plus sign
    specialArray[idx] = /&#44;/gi;        replacementArray[idx++] = ",";                 // , comma
    specialArray[idx] = /&#45;/gi;        replacementArray[idx++] = "-";                 // - hyphen
    specialArray[idx] = /&#46;/gi;        replacementArray[idx++] = ".";                 // . period
    specialArray[idx] = /&frasl;/gi;      replacementArray[idx++] = "/";                 // / slash
    specialArray[idx] = /&#47;/gi;        replacementArray[idx++] = "/";                 // / slash
    specialArray[idx] = /&#58;/gi;        replacementArray[idx++] = ":";                 // : colon
    specialArray[idx] = /&#59;/gi;        replacementArray[idx++] = ";";                 // ; semicolon
    specialArray[idx] = /&lt;/gi;         replacementArray[idx++] = "<";                 // < less-than sign
    specialArray[idx] = /&#60;/gi;        replacementArray[idx++] = "<";                 // < less-than sign
    specialArray[idx] = /&#61;/gi;        replacementArray[idx++] = "= ";                // = equals sign
    specialArray[idx] = /&gt;/gi;         replacementArray[idx++] = ">";                 // > greater-than sign
    specialArray[idx] = /&#62;/gi;        replacementArray[idx++] = ">";                 // > greater-than sign
    specialArray[idx] = /&#63;/gi;        replacementArray[idx++] = "?";                 // ? question mark
    specialArray[idx] = /&#64;/gi;        replacementArray[idx++] = "@";                 // @ at sign
    specialArray[idx] = /&#91;/gi;        replacementArray[idx++] = "[";                 // [ left square bracket
    specialArray[idx] = /&#92;/gi;        replacementArray[idx++] = "\\";                // \ backslash
    specialArray[idx] = /&#93;/gi;        replacementArray[idx++] = "]";                 // ] right square bracket
    specialArray[idx] = /&#94;/gi;        replacementArray[idx++] = "^";                 // ^ caret
    specialArray[idx] = /&#95;/gi;        replacementArray[idx++] = "_";                 // _ horizontal bar (underscore)
    specialArray[idx] = /&#96;/gi;        replacementArray[idx++] = "";                  // ` grave accent
    specialArray[idx] = /&#123;/gi;       replacementArray[idx++] = "{";                 // { left curly brace
    specialArray[idx] = /&#124;/gi;       replacementArray[idx++] = "|";                 // | vertical bar
    specialArray[idx] = /&#125;/gi;       replacementArray[idx++] = "}";                 // } right curly brace
    specialArray[idx] = /&#126;/gi;       replacementArray[idx++] = "~";                 // ~ tilde
    specialArray[idx] = /&ndash;/gi;      replacementArray[idx++] = "-";                 //
    specialArray[idx] = /&#150;/gi;       replacementArray[idx++] = "-";                 //  en dash
    specialArray[idx] = /&mdash;/gi;      replacementArray[idx++] = "--";                // em dash
    specialArray[idx] = /&#151;/gi;       replacementArray[idx++] = "--";                //  em dash
    specialArray[idx] = /&nbsp;/gi;       replacementArray[idx++] = " ";                  //
    specialArray[idx] = /&#160;/gi;       replacementArray[idx++] = "";                  // nonbreaking space
    specialArray[idx] = /&iexcl;/gi;      replacementArray[idx++] = "";                 //
    specialArray[idx] = /&#161;/gi;       replacementArray[idx++] = "";                 //  inverted exclamation
    specialArray[idx] = /&cent;/gi;       replacementArray[idx++] = "c";                 //
    specialArray[idx] = /&#162;/gi;       replacementArray[idx++] = "c";                 //  cent sign
    specialArray[idx] = /&pound;/gi;      replacementArray[idx++] = "L";                 //
    specialArray[idx] = /&#163;/gi;       replacementArray[idx++] = "l";                 //  pound sterling
    specialArray[idx] = /&curren;/gi;     replacementArray[idx++] = "$";                 //
    specialArray[idx] = /&#164;/gi;       replacementArray[idx++] = "$";                 //  general currency sign
    specialArray[idx] = /&yen;/gi;        replacementArray[idx++] = "Y";                 //
    specialArray[idx] = /&#165;/gi;       replacementArray[idx++] = "Y";                 //  yen sign
    specialArray[idx] = /&brvbar;/gi;     replacementArray[idx++] = "";                 // broken vertical bar
    specialArray[idx] = /&brkbar;/gi;     replacementArray[idx++] = "";                 // broken vertical bar
    specialArray[idx] = /&#166;/gi;       replacementArray[idx++] = "";                 //  broken vertical bar
    specialArray[idx] = /&sect;/gi;       replacementArray[idx++] = "S";                 //
    specialArray[idx] = /&#167;/gi;       replacementArray[idx++] = "S";                 //  section sign
    specialArray[idx] = /&uml;/gi;        replacementArray[idx++] = "";                  // umlaut
    specialArray[idx] = /&die;/gi;        replacementArray[idx++] = "";                  //
    specialArray[idx] = /&#168;/gi;       replacementArray[idx++] = "";                  //  umlaut
    specialArray[idx] = /&copy;/gi;       replacementArray[idx++] = "c";                 //
    specialArray[idx] = /&#169;/gi;       replacementArray[idx++] = "c";                 //  copyright
    specialArray[idx] = /&ordf;/gi;       replacementArray[idx++] = "a";                 //
    specialArray[idx] = /&#170;/gi;       replacementArray[idx++] = "a";                 //  feminine ordinal
    specialArray[idx] = /&laquo;/gi;      replacementArray[idx++] = "<<";                //
    specialArray[idx] = /&#171;/gi;       replacementArray[idx++] = "<<";                //  left angle quote
    specialArray[idx] = /&not;/gi;        replacementArray[idx++] = "!";                 //
    specialArray[idx] = /&#172;/gi;       replacementArray[idx++] = "!";                 //  not sign
    specialArray[idx] = /&shy;/gi;        replacementArray[idx++] = "-";                 //
    specialArray[idx] = /&#173;/gi;       replacementArray[idx++] = "-";                 //  soft hyphen
    specialArray[idx] = /&reg;/gi;        replacementArray[idx++] = " R";                 //
    specialArray[idx] = /&#174;/gi;       replacementArray[idx++] = " R";                 //  registered trademark
    specialArray[idx] = /&macr;/gi;       replacementArray[idx++] = "";                  // macron accent
    specialArray[idx] = /&hibar;/gi;      replacementArray[idx++] = "";                  //macron accent
    specialArray[idx] = /&#175;/gi;       replacementArray[idx++] = "";                  //  macron accent
    specialArray[idx] = /&deg;/gi;        replacementArray[idx++] = "deg";               //
    specialArray[idx] = /&#176;/gi;       replacementArray[idx++] = "deg";               //  degree sign
    specialArray[idx] = /&plusmn;/gi;     replacementArray[idx++] = "+-";                //
    specialArray[idx] = /&#177;/gi;       replacementArray[idx++] = "+-";                //  plus or minus
    specialArray[idx] = /&sup2;/gi;       replacementArray[idx++] = "^2"                 //
    specialArray[idx] = /&#178;/gi;       replacementArray[idx++] = "^2";                //  superscript two
    specialArray[idx] = /&sup3;/gi;       replacementArray[idx++] = "^3";                //
    specialArray[idx] = /&#179;/gi;       replacementArray[idx++] = "^3";                //  superscript three
    specialArray[idx] = /&acute;/gi;      replacementArray[idx++] = "";                  //
    specialArray[idx] = /&#180;/gi;       replacementArray[idx++] = "";                  //  acute accent
    specialArray[idx] = /&micro;/gi;      replacementArray[idx++] = "u";                 //
    specialArray[idx] = /&#181;/gi;       replacementArray[idx++] = "u";                 //  micro sign
    specialArray[idx] = /&para;/gi;       replacementArray[idx++] = "";                  //
    specialArray[idx] = /&#182;/gi;       replacementArray[idx++] = "";                  //  paragraph sign
    specialArray[idx] = /&middot;/gi;     replacementArray[idx++] = "";                  //
    specialArray[idx] = /&#183;/gi;       replacementArray[idx++] = "";                  //  middle dot
    specialArray[idx] = /&cedil;/gi;      replacementArray[idx++] = "";                  //
    specialArray[idx] = /&#184;/gi;       replacementArray[idx++] = "";                  //  cedilla
    specialArray[idx] = /&sup1;/gi;       replacementArray[idx++] = "^1";                //
    specialArray[idx] = /&#185;/gi;       replacementArray[idx++] = "^1";                //  superscript one
    specialArray[idx] = /&ordm;/gi;       replacementArray[idx++] = "o";                 //
    specialArray[idx] = /&#186;/gi;       replacementArray[idx++] = "o";                 //  masculine ordinal
    specialArray[idx] = /&raquo;/gi;      replacementArray[idx++] = ">>";                //
    specialArray[idx] = /&#187;/gi;       replacementArray[idx++] = ">>";                //  right angle quote
    specialArray[idx] = /&frac14;/gi;     replacementArray[idx++] = " 1/4";               //
    specialArray[idx] = /&#188;/gi;       replacementArray[idx++] = " 1/4";               //  one-fourth
    specialArray[idx] = /&frac12;/gi;     replacementArray[idx++] = " 1/2";               //
    specialArray[idx] = /&#189;/gi;       replacementArray[idx++] = " 1/2"                //  one-half
    specialArray[idx] = /&frac34;/gi;     replacementArray[idx++] = " 3/4";               //
    specialArray[idx] = /&#190;/gi;       replacementArray[idx++] = " 3/4";               //  three-fourths
    specialArray[idx] = /&iquest;/gi;     replacementArray[idx++] = "?";                 //
    specialArray[idx] = /&#191;/gi;       replacementArray[idx++] = "?";                 //  inverted question mark
    specialArray[idx] = /&Agrave;/gi;     replacementArray[idx++] = "A";                 //
    specialArray[idx] = /&#192;/gi;       replacementArray[idx++] = "A";                 //  uppercase A, grave accent
    specialArray[idx] = /&Aacute;/gi;     replacementArray[idx++] = "A";                 //
    specialArray[idx] = /&#193;/gi;       replacementArray[idx++] = "A";                 //  uppercase A, acute accent
    specialArray[idx] = /&Acirc;/gi;      replacementArray[idx++] = "A";                 //
    specialArray[idx] = /&#194;/gi;       replacementArray[idx++] = "A";                 //  uppercase A, circumflex accent
    specialArray[idx] = /&Atilde;/gi;     replacementArray[idx++] = "A";                 //
    specialArray[idx] = /&#195;/gi;       replacementArray[idx++] = "A";                 //  uppercase A, tilde
    specialArray[idx] = /&Auml;/gi;       replacementArray[idx++] = "A";                 //
    specialArray[idx] = /&#196;/gi;       replacementArray[idx++] = "A";                 //  uppercase A, umlaut
    specialArray[idx] = /&Aring;/gi;      replacementArray[idx++] = "A";                 //
    specialArray[idx] = /&#197;/gi;       replacementArray[idx++] = "A";                 //  uppercase A, ring
    specialArray[idx] = /&AElig;/gi;      replacementArray[idx++] = "AE";                //
    specialArray[idx] = /&#198;/gi;       replacementArray[idx++] = "AE";                //  uppercase AE
    specialArray[idx] = /&Ccedil;/gi;     replacementArray[idx++] = "C";                 //
    specialArray[idx] = /&#199;/gi;       replacementArray[idx++] = "C";                 //  uppercase C, cedilla
    specialArray[idx] = /&Egrave;/gi;     replacementArray[idx++] = "E";                 //
    specialArray[idx] = /&#200;/gi;       replacementArray[idx++] = "E";                 //  uppercase E, grave accent
    specialArray[idx] = /&Eacute;/gi;     replacementArray[idx++] = "E";                 //
    specialArray[idx] = /&#201;/gi;       replacementArray[idx++] = "E";                 //  uppercase E, acute accent
    specialArray[idx] = /&Ecirc;/gi;      replacementArray[idx++] = "E";                 //
    specialArray[idx] = /&#202;/gi;       replacementArray[idx++] = "E";                 //  uppercase E, circumflex accent
    specialArray[idx] = /&Euml;/gi;       replacementArray[idx++] = "E";                 //
    specialArray[idx] = /&#203;/gi;       replacementArray[idx++] = "E";                 //  uppercase E, umlaut
    specialArray[idx] = /&Igrave;/gi;     replacementArray[idx++] = "I";                 //
    specialArray[idx] = /&#204;/gi;       replacementArray[idx++] = "I";                 //  uppercase I, grave accent
    specialArray[idx] = /&Iacute;/gi;     replacementArray[idx++] = "I";                 //
    specialArray[idx] = /&#205;/gi;       replacementArray[idx++] = "I";                 //  uppercase I, acute accent
    specialArray[idx] = /&Icirc;/gi;      replacementArray[idx++] = "I";                 //
    specialArray[idx] = /&#206;/gi;       replacementArray[idx++] = "I";                 //  uppercase I, circumflex accent
    specialArray[idx] = /&Iuml;/gi;       replacementArray[idx++] = "I";                 //
    specialArray[idx] = /&#207;/gi;       replacementArray[idx++] = "I";                 //  uppercase I, umlaut
    specialArray[idx] = /&ETH;/gi;        replacementArray[idx++] = "D";                 //
    specialArray[idx] = /&#208;/gi;       replacementArray[idx++] = "D";                 //  uppercase Eth, Icelandic
    specialArray[idx] = /&Ntilde;/gi;     replacementArray[idx++] = "N";                 //
    specialArray[idx] = /&#209;/gi;       replacementArray[idx++] = "N";                 //  uppercase N, tilde
    specialArray[idx] = /&Ograve;/gi;     replacementArray[idx++] = "O";                 //
    specialArray[idx] = /&#210;/gi;       replacementArray[idx++] = "O";                 //  uppercase O, grave accent
    specialArray[idx] = /&Oacute;/gi;     replacementArray[idx++] = "O";                 //
    specialArray[idx] = /&#211;/gi;       replacementArray[idx++] = "O";                 //  uppercase O, acute accent
    specialArray[idx] = /&Ocirc;/gi;      replacementArray[idx++] = "O";                 //
    specialArray[idx] = /&#212;/gi;       replacementArray[idx++] = "O";                 //  uppercase O, circumflex accent
    specialArray[idx] = /&Otilde;/gi;     replacementArray[idx++] = "O";                 //
    specialArray[idx] = /&#213;/gi;       replacementArray[idx++] = "O";                 //  uppercase O, tilde
    specialArray[idx] = /&Ouml;/gi;       replacementArray[idx++] = "O";                 //
    specialArray[idx] = /&#214;/gi;       replacementArray[idx++] = "O";                 //  uppercase O, umlaut
    specialArray[idx] = /&times;/gi;      replacementArray[idx++] = "x";                 //
    specialArray[idx] = /&#215;/gi;       replacementArray[idx++] = "x";                 //  multiplication sign
    specialArray[idx] = /&Oslash;/gi;     replacementArray[idx++] = "O";                 //
    specialArray[idx] = /&#216;/gi;       replacementArray[idx++] = "O";                 //  uppercase O, slash
    specialArray[idx] = /&Ugrave;/gi;     replacementArray[idx++] = "U";                 //
    specialArray[idx] = /&#217;/gi;       replacementArray[idx++] = "U";                 //  uppercase U, grave accent
    specialArray[idx] = /&Uacute;/gi;     replacementArray[idx++] = "U";                 //
    specialArray[idx] = /&#218;/gi;       replacementArray[idx++] = "U";                 //  uppercase U, acute accent
    specialArray[idx] = /&Ucirc;/gi;      replacementArray[idx++] = "U";                 //
    specialArray[idx] = /&#219;/gi;       replacementArray[idx++] = "U";                 //  uppercase U, circumflex accent
    specialArray[idx] = /&Uuml;/gi;       replacementArray[idx++] = "U";                 //
    specialArray[idx] = /&#220;/gi;       replacementArray[idx++] = "U";                 //  uppercase U, umlaut
    specialArray[idx] = /&Yacute;/gi;     replacementArray[idx++] = "Y";                 //
    specialArray[idx] = /&#221;/gi;       replacementArray[idx++] = "Y";                 //  uppercase Y, acute accent
    specialArray[idx] = /&THORN;/gi;      replacementArray[idx++] = "P";                 //
    specialArray[idx] = /&#222;/gi;       replacementArray[idx++] = "P";                 //  uppercase THORN, Icelandic
    specialArray[idx] = /&szlig;/gi;      replacementArray[idx++] = "B";                 //
    specialArray[idx] = /&#223;/gi;       replacementArray[idx++] = "B";                 //  lowercase sharps, German
    specialArray[idx] = /&agrave;/gi;     replacementArray[idx++] = "a";                 //
    specialArray[idx] = /&#224;/gi;       replacementArray[idx++] = "a";                 //  lowercase a, grave accent
    specialArray[idx] = /&aacute;/gi;     replacementArray[idx++] = "a";                 //
    specialArray[idx] = /&#225;/gi;       replacementArray[idx++] = "a";                 //  lowercase a, acute accent
    specialArray[idx] = /&acirc;/gi;      replacementArray[idx++] = "a";                 //
    specialArray[idx] = /&#226;/gi;       replacementArray[idx++] = "a";                 //  lowercase a, circumflex accent
    specialArray[idx] = /&atilde;/gi;     replacementArray[idx++] = "a";                 //
    specialArray[idx] = /&#227;/gi;       replacementArray[idx++] = "a";                 //  lowercase a, tilde
    specialArray[idx] = /&auml;/gi;       replacementArray[idx++] = "a";                 //
    specialArray[idx] = /&#228;/gi;       replacementArray[idx++] = "a";                 //  lowercase a, umlaut
    specialArray[idx] = /&aring;/gi;      replacementArray[idx++] = "a";                 //
    specialArray[idx] = /&#229;/gi;       replacementArray[idx++] = "a";                 //  lowercase a, ring
    specialArray[idx] = /&aelig;/gi;      replacementArray[idx++] = "ae";                //
    specialArray[idx] = /&#230;/gi;       replacementArray[idx++] = "ae";                //  lowercase ae
    specialArray[idx] = /&ccedil;/gi;     replacementArray[idx++] = "c";                 //
    specialArray[idx] = /&#231;/gi;       replacementArray[idx++] = "c";                 //  lowercase c, cedilla
    specialArray[idx] = /&egrave;/gi;     replacementArray[idx++] = "e";                 //
    specialArray[idx] = /&#232;/gi;       replacementArray[idx++] = "e";                 //  lowercase e, grave accent
    specialArray[idx] = /&eacute;/gi;     replacementArray[idx++] = "e";                 //
    specialArray[idx] = /&#233;/gi;       replacementArray[idx++] = "e";                 //  lowercase e, acute accent
    specialArray[idx] = /&ecirc;/gi;      replacementArray[idx++] = "e";                 //
    specialArray[idx] = /&#234;/gi;       replacementArray[idx++] = "e";                 //  lowercase e, circumflex accent
    specialArray[idx] = /&euml;/gi;       replacementArray[idx++] = "e";                 //
    specialArray[idx] = /&#235;/gi;       replacementArray[idx++] = "e";                 //  lowercase e, umlaut
    specialArray[idx] = /&igrave;/gi;     replacementArray[idx++] = "i";                 //
    specialArray[idx] = /&#236;/gi;       replacementArray[idx++] = "i";                 //  lowercase i, grave accent
    specialArray[idx] = /&iacute;/gi;     replacementArray[idx++] = "i";                 //
    specialArray[idx] = /&#237;/gi;       replacementArray[idx++] = "i";                 //  lowercase i, acute accent
    specialArray[idx] = /&icirc;/gi;      replacementArray[idx++] = "i";                 //
    specialArray[idx] = /&#238;/gi;       replacementArray[idx++] = "i";                 //  lowercase i, circumflex accent
    specialArray[idx] = /&iuml;/gi;       replacementArray[idx++] = "i";                 //
    specialArray[idx] = /&#239;/gi;       replacementArray[idx++] = "i";                 //  lowercase i, umlaut
    specialArray[idx] = /&eth;/gi;        replacementArray[idx++] = "o";                 //
    specialArray[idx] = /&#240;/gi;       replacementArray[idx++] = "o";                 //  lowercase eth, Icelandic
    specialArray[idx] = /&ntilde;/gi;     replacementArray[idx++] = "n";                 //
    specialArray[idx] = /&#241;/gi;       replacementArray[idx++] = "n";                 //  lowercase n, tilde
    specialArray[idx] = /&ograve;/gi;     replacementArray[idx++] = "o";                 //
    specialArray[idx] = /&#242;/gi;       replacementArray[idx++] = "o";                 //  lowercase o, grave accent
    specialArray[idx] = /&oacute;/gi;     replacementArray[idx++] = "o";                 //
    specialArray[idx] = /&#243;/gi;       replacementArray[idx++] = "o";                 //  lowercase o, acute accent
    specialArray[idx] = /&ocirc;/gi;      replacementArray[idx++] = "o";                 //
    specialArray[idx] = /&#244;/gi;       replacementArray[idx++] = "o";                 //  lowercase o, circumflex accent
    specialArray[idx] = /&otilde;/gi;     replacementArray[idx++] = "o";                 //
    specialArray[idx] = /&#245;/gi;       replacementArray[idx++] = "o";                 //  lowercase o, tilde
    specialArray[idx] = /&ouml;/gi;       replacementArray[idx++] = "o";                 //
    specialArray[idx] = /&#246;/gi;       replacementArray[idx++] = "o";                 //  lowercase o, umlaut
    specialArray[idx] = /&divide;/gi;     replacementArray[idx++] = "/";                 //
    specialArray[idx] = /&#247;/gi;       replacementArray[idx++] = "/";                 //  division sign
    specialArray[idx] = /&oslash;/gi;     replacementArray[idx++] = "o";                 //
    specialArray[idx] = /&#248;/gi;       replacementArray[idx++] = "o";                 //  lowercase o, slash
    specialArray[idx] = /&ugrave;/gi;     replacementArray[idx++] = "u";                 //
    specialArray[idx] = /&#249;/gi;       replacementArray[idx++] = "u";                 //  lowercase u, grave accent
    specialArray[idx] = /&uacute;/gi;     replacementArray[idx++] = "u";                 //
    specialArray[idx] = /&#250;/gi;       replacementArray[idx++] = "u";                 //  lowercase u, acute accent
    specialArray[idx] = /&ucirc;/gi;      replacementArray[idx++] = "u";                 //
    specialArray[idx] = /&#251;/gi;       replacementArray[idx++] = "u";                 //  lowercase u, circumflex accent
    specialArray[idx] = /&uuml;/gi;       replacementArray[idx++] = "u";                 //
    specialArray[idx] = /&#252;/gi;       replacementArray[idx++] = "u";                 //  lowercase u, umlaut
    specialArray[idx] = /&yacute;/gi;     replacementArray[idx++] = "y";                 //
    specialArray[idx] = /&#253;/gi;       replacementArray[idx++] = "y";                 //  lowercase y, acute accent
    specialArray[idx] = /&thorn;/gi;      replacementArray[idx++] = "p";                 //
    specialArray[idx] = /&#254;/gi;       replacementArray[idx++] = "p";                 //  lowercase thorn, Icelandic
    specialArray[idx] = /&yuml;/gi;       replacementArray[idx++] = "y";                 //
    specialArray[idx] = /&#255;/gi;       replacementArray[idx++] = "y";                 //  lowercase y, umlaut
    specialArray[idx] = /&#009;/gi;       replacementArray[idx++] = " ";                 // horizontal tab
    specialArray[idx] = /&#010;/gi;       replacementArray[idx++] = " ";                 // line feed
    specialArray[idx] = /&#032;/gi;       replacementArray[idx++] = " ";                 // space
    specialArray[idx] = /&#033;/gi;       replacementArray[idx++] = "!";                 // ! exclamation mark
    specialArray[idx] = /&#034;/gi;       replacementArray[idx++] = "\"";                // " double quotation mark
    specialArray[idx] = /&#035;/gi;       replacementArray[idx++] = "#";                 // # number sign
    specialArray[idx] = /&#036;/gi;       replacementArray[idx++] = "$";                 // $ dollar sign
    specialArray[idx] = /&#037;/gi;       replacementArray[idx++] = "%";                 // % percent sign
    specialArray[idx] = /&#038;/gi;       replacementArray[idx++] = "&";                 // & ampersand
    specialArray[idx] = /&#039;/gi;       replacementArray[idx++] = "'";                 // ' apostrophe
    specialArray[idx] = /&#040;/gi;       replacementArray[idx++] = "(";                 // ( left parenthesis
    specialArray[idx] = /&#041;/gi;       replacementArray[idx++] = ")";                 // ) right parenthesis
    specialArray[idx] = /&#042;/gi;       replacementArray[idx++] = "*";                 // * asterisk
    specialArray[idx] = /&#043;/gi;       replacementArray[idx++] = "+";                 // + plus sign
    specialArray[idx] = /&#044;/gi;       replacementArray[idx++] = ",";                 // , comma
    specialArray[idx] = /&#045;/gi;       replacementArray[idx++] = "-";                 // - hyphen
    specialArray[idx] = /&#046;/gi;       replacementArray[idx++] = ".";                 // . period
    specialArray[idx] = /&#047;/gi;       replacementArray[idx++] = "/";                 // / slash
    specialArray[idx] = /&#058;/gi;       replacementArray[idx++] = ":";                 // : colon
    specialArray[idx] = /&#059;/gi;       replacementArray[idx++] = ";";                 // ; semicolon
    specialArray[idx] = /&#060;/gi;       replacementArray[idx++] = "<";                 // < less-than sign
    specialArray[idx] = /&#061;/gi;       replacementArray[idx++] = "=";                 // = equals sign
    specialArray[idx] = /&#062;/gi;       replacementArray[idx++] = ">";                 // > greater-than sign
    specialArray[idx] = /&#063;/gi;       replacementArray[idx++] = "?";                 // ? question mark
    specialArray[idx] = /&#064;/gi;       replacementArray[idx++] = "@";                 // @ at sign
    specialArray[idx] = /&#091;/gi;       replacementArray[idx++] = "[";                 // [ left square bracket
    specialArray[idx] = /&#092;/gi;       replacementArray[idx++] = "\\";                // \ backslash
    specialArray[idx] = /&#093;/gi;       replacementArray[idx++] = "]";                 // ] right square bracket
    specialArray[idx] = /&#094;/gi;       replacementArray[idx++] = "^";                 // ^ caret
    specialArray[idx] = /&#095;/gi;       replacementArray[idx++] = "_";                 // _ horizontal bar (underscore)
    specialArray[idx] = /&#096;/gi;       replacementArray[idx++] = "";                  // ` grave accent

    specialArraysInitted=true;
}

function cleanHTML(mystr) {
    //replace multiple whitespaces with one
    //removes javascript comments and other html tags
    //replaces all special html characters
    mystr = "" + mystr;
    mystr = mystr.replace(/<br>/gi, ' ');
    mystr= mystr.replace(/<[^<]*>/g, '').replace(/^\s+/g, '').replace(/\s+$/g, '');

    for (var i=0; i < specialArray.length; i++)
        mystr=mystr.replace(specialArray[i],replacementArray[i]);

    mystr =  mystr.replace(/^\s+/g, '').replace(/\s+$/g, '').replace(/\s[\s]+/g, ' ');

    return mystr;
}