/*   JavaScript code for use with NHL Team Schedule Widget.
 *   Copyright (C) 2005 Sarah Tuohy <sjt2005@gmail.com>
 *   Displays the standings for a particular conference for the current
 *   season.
 *
 *   This work is licensed under the Creative Commons Attribution-NonCommercial-
 *   ShareAlike License. To view a copy of this license, visit
 *   http://creativecommons.org/licenses/by-nc-sa/2.5/ or send a letter to
 *   Creative Commons, 543 Howard Street, 5th Floor, San Francisco, California,
 *   94105, USA.
 *
 *   A copy of the license was also distributed with this widget.
 */

 //////////////////////////////////////////////////////////////////////////////////
 // FileName: fetchConferenceStandings.js
 // Description: updates the schedule grid to display conference standings
 //////////////////////////////////////////////////////////////////////////////////

function fetchConferenceStandings(myConference, imageOpacity, gameTextOpacity, rowSrc,
                                  headerRowSrc, widest, backgroundOffset,
                                  urlData) {

    var regexSection = new RegExp("<tr class=\"stathead\">[\\s]*<td colspan=(\")?([\\d]*)(\")?>" + myConference +"<\\/td>([.\\s\\S]*?)(<tr class=\"stathead\">|<\\/body>)", "im");

    var regexRow = /<TR[^<>]*class="?(colhead|evenrow|oddrow)[^<>]*>([.\s\S]*?)<\/TR>/gim;
    var regexCell = /<TD[^<>]*>([.\s\S]*?)(<\/TD>)/gim;

    var section = regexSection.exec( urlData );
    var colCount = 0;

    customZOrder = fakeRow.zOrder + 1; //global
    var rowCount=0;

    for (var i=0; i < display.length; i++)
        widest[i]=0;

    if (section) {

        var isHeader = false;

        while (rows = regexRow.exec( section[4] ) ) {
            var colorize;
            var font;
            var fontSize;
            var textColor;

            if (rows[1]=="colhead") {
                isHeader =true;
                colorize=  (preferences.colorizeHeaderRow.value=="1") ? preferences.headerRowColor.value : "";
                font = preferences.headerTextFont.value;
                textColor=preferences.headerTextColor.value;
                fontSize=preferences.headerTextSize.value;
                addBGRow(rowCount, backgroundOffset, colorize, imageOpacity,headerRowSrc);
            }
            else {
                isHeader=false;
                colorize =  (preferences.colorizeRows.value=="1") ? preferences.rowColor.value : "";
                font = preferences.textFont.value;
                textColor=preferences.awayTextColor.value;
                fontSize=preferences.textSize.value;
                addBGRow(rowCount, backgroundOffset, colorize, imageOpacity,rowSrc);
            }

            addTextRow(rowCount, textColor, font, fontSize, gameTextOpacity);

            colCount=0;

            while (cells = regexCell.exec(rows[2]) ) {
                var cellData = cleanHTML(cells[1]);
                if (colCount < display.length && display[colCount]=="1") {
                    if (cellData=="") {
                        if (isHeader) {
                            if (preferences.conferenceGroup.value=="conference") {
                                if (colCount==0)
                                    cellData = "RNK";
                                else if (colCount==1)
                                    cellData = "TEAM";
                                else
                                    cellData = " ";
                            }
                            else
                                if (colCount==0)
                                    cellData = "TEAM";
                                else
                                    cellData = " ";
                        }
                        else
                            cellData = " " ;
                    }
                    games[rowCount][colCount].data = cellData;
                }

                colCount++;
             }

            var tallest = 0;
            if (preferences.conferenceGroup.value=="conference")
                tallest = games[rowCount][1].height;
            else
                tallest = games[rowCount][0].height;

            for (var i=0; i < display.length; i++){
                if (games[rowCount][i]!=null)
                    games[rowCount][i].vOffset = backgroundOffset + tallest;

                if (display[i]=="1") {
                    if (games[rowCount][i].width > widest[i])
                        widest[i] = games[rowCount][i].width;

                }//if
            }

            backgroundImages[rowCount].height  =tallest+padding;

            for (var i=0; i < display.length; i++){
                if (games[rowCount][i]!=null)
                    games[rowCount][i].vOffset = backgroundImages[rowCount].vOffset + backgroundImages[rowCount].height - padding/1.5;
            }
            backgroundOffset += backgroundImages[rowCount].height;
            rowCount++;
        }
    }

    return rowCount;

}