/*   JavaScript code for NBA Schedule Widgets.
 *   Copyright (C) 2005 Sarah Tuohy <sjt2005@gmail.com>
 *   Displays NBA schedule for the selected team.
 *
 *   This work is licensed under the Creative Commons Attribution-NonCommercial-
 *   ShareAlike License. To view a copy of this license, visit
 *   http://creativecommons.org/licenses/by-nc-sa/2.5/ or send a letter to
 *   Creative Commons, 543 Howard Street, 5th Floor, San Francisco, California,
 *   94105, USA.
 *
 *   A copy of the license was also distributed with this widget.
 */

 //////////////////////////////////////////////////////////////////////////////////
 // FileName: fetchData.js
 // Description: updates the schedule grid.  also contains many other javascript
 //              functions for cleaning and displaying data
 //////////////////////////////////////////////////////////////////////////////////
    var customZOrder=0;
    var currentArraySize=0;
    var url = new URL();

    include("cleanHTML.js");
    include("fetchConferenceStandings.js");

    function updateTimestamp() {
        var temp = Date().split(' ');
        var lastUpdate = temp[0] + ' ' + temp[1]+' ' +temp[2]+' ' +temp[3] +' ' + temp[4];

        return "Last updated: " + lastUpdate
    }

    function trimString (str) {
        try {
            return str.replace(/^\s+/g, '').replace(/\s+$/g, '');
        } catch(e) {
            //alert("error!");
            return "";
        }
    }

    function convertMonth(myMonth) {
        var months= new Array();
        months[0]="";
        months[1]="";
        months[2]="";
        months[3]="";

        switch (myMonth) {
            case 10:
                months[0]="Oct";
                months[1]="Nov";
                months[2]="October";
                months[3]="November";
                break;
            case 11:
                months[0]="Nov";
                months[1]="Dec";
                months[2]="November";
                months[3]="December";
                break;
            case 12:
                months[0]="Dec";
                months[1]="Jan";
                months[2]="December";
                months[3]="January";
                break;
            case 1:
                months[0]="Jan";
                months[1]="Feb";
                months[2]="January";
                months[3]="February";
                break;
            case 2:
                months[0]="Feb";
                months[1]="Mar";
                months[2]="February";
                months[3]="March";
                break;
            case 3:
                months[0]="Mar";
                months[1]="Apr";
                months[2]="March";
                months[3]="April";
                break;
            case 4:
                months[0]="Apr";
                months[1]="May";
                months[2]="April";
                months[3]="May";
                break;
            case 5:
                months[0]="May";
                months[1]="Jun";
                months[2]="May";
                months[3]="June";
                break;
            case 6:
                months[0]="Jun";
                months[2]="June";
        }
        return months;
    }

   function adjustTime(time) {
      //i realize this won't work if a game time is close to midnite, because
      //then the date should also change. luckily, as far as i know, no games happen
      //in the wee hours of the morning.

      //since i'm scraping from multiple pages, the time string wasn't consistent
      // in it's case (e.g. "a.m." or "AM", let's uppercase the whole thing
      //also, some pages listed 9:00 pm as "9 pm", so let's make that more consistent
      //too and prepend a 0 to the hour if necessary (makes layout prettier if we have
      //1 pm and 11 am in the same schedule)
      try {
          if (time==null || time.length==0)
              return "";

          myTime = time;
          if (myTime.length > 0) {
              //and make sure all P.M. are pm and A.M. are am

              myTime = myTime.replace(/P[\.]?M[\.]?/gi, "pm");
              myTime = myTime.replace(/A[\.]?M[\.]?/gi, "am");

          }

          var isShortHourFmt = false;
          var pos = myTime.indexOf(":");

          if (pos==-1) {
              isShortHourFmt = true;
               pos = myTime.indexOf(" ");
          }
          var hour = parseInt(myTime.substring(0, pos));

          if (isNaN(hour))
              return time;

          var remainder = myTime.substring(pos, myTime.length);

          var tzOffset = parseInt(preferences.timezoneOffset.value);
          if (!tzOffset==0 && !myTime.length==0) {

              if (hour==12)
                  hour==0;

              hour += tzOffset;

              if (hour < 0)
                  remainder = remainder.replace(/pm/gi, "am");

              //this means we've gone from a pm time to an am time
              if (hour<=0)
                  hour += 12;

          }
          if (isShortHourFmt)
              remainder = ":00" + remainder;

          if (hour < 10)
              return "0" + hour + remainder;
          else
              return hour + remainder;

      } catch (e) {
          return time;
      }
    }

    function addBGRow(row, voffset, colorize, bgOpacity, rowsrc){
        backgroundImages[row]= new Image();
        backgroundImages[row].vOffset = voffset;
        backgroundImages[row].opacity = bgOpacity;
        backgroundImages[row].hOffset = defaultRowHOffset;
        backgroundImages[row].src =rowsrc;
        backgroundImages[row].zOrder = customZOrder++;
        backgroundImages[row].colorize= colorize;

        if (row==0)
            backgroundImages[row].tooltip =  preferences.dataSource.value =="0" ? "Now showing: AOL" : "Now showing: ESPN";

    }

    function addTextRow(row, textColor, textFont, textSize, textOpacity) {
        games[row] = new Array();

        for (var i=0; i < display.length; i++)  {
            if (display[i]=="1") {
                games[row][i] = new Text();
                games[row][i].width=-1; //width is dynamic
                games[row][i].vOffset= 0;

                games[row][i].hOffset=0;

                games[row][i].bgColor = "#000000";

                games[row][i].alignment = "left";

                games[row][i].opacity = textOpacity;

                games[row][i].color = textColor;
                games[row][i].font = textFont;
                games[row][i].size = textSize;

                games[row][i].zOrder = customZOrder++;
            } //end if
        } //end for

    }

    function loadPreferences() {
        if (preferences.displayConferenceStandings.value=="0") {

            display[0] =  preferences.showDay.value;
            display[1] =  preferences.showDate.value;
            display[2] =  "1";
            display[3] =  preferences.showTime.value;
            display[4] =  preferences.showLocaltv.value;
            display[5] =  preferences.showNationaltv.value;
            display[6] =  preferences.showRadio.value;
            display[7] =  preferences.showHiAssists.value;

            display[8] =  "0";
            display[9] =  "0";
            display[10] =  "0";
            display[11] =  "0";
            display[12] =  "0";
            display[13] =  "0";

        }
        else {
        //NAME W L PCT GB HM RD CONF DIV PF PA STRK L10
        //RNK NAME W L PCT GB HM RD CONF DIV PF PA STRK L10
            if (preferences.conferenceGroup.value=="division") {
                display[0] =  "1";
                display[1] =  preferences.showW.value;
                display[2] = preferences.showL.value;
                display[3] = preferences.showPCT.value;
                display[4] = preferences.showGB.value;
                display[5] = preferences.showHM.value;
                display[6] = preferences.showRD.value;
                display[7] = preferences.showCONF.value;

                display[8] = preferences.showDIV.value;
                display[9] = preferences.showPF.value;
                display[10] = preferences.showPA.value;
                display[11] = preferences.showSTRK.value;
                display[12] = preferences.showL10.value;
            }
            else {
                display[0] = preferences.showRank.value;
                display[1] =  "1";
                display[2] = preferences.showW.value;
                display[3] = preferences.showL.value;
                display[4] = preferences.showPCT.value;
                display[5] = preferences.showGB.value;
                display[6] = preferences.showHM.value;
                display[7] = preferences.showRD.value;
                display[8] = preferences.showCONF.value;

                display[9] = preferences.showDIV.value;
                display[10] = preferences.showPF.value;
                display[11] = preferences.showPA.value;
                display[12] = preferences.showSTRK.value;
                display[13] = preferences.showL10.value;
            }

        }
        var regexYear = /^\d{4}/;

        var goodYear = true;

        var ilLimitYear = 2002;
        var iuLimitYear = currentSeason;

        if (!preferences.year.value.match(regexYear) )  {
            goodYear = false;
        }
        else  {
            var iYear = parseInt(preferences.year.value);
            if (iYear < ilLimitYear || iYear > iuLimitYear) {
                goodYear = false;
            }
        }

        if (!goodYear) {
                alert("You have specified an invalid year.  Year must be between " + ilLimitYear + " and " + iuLimitYear + ", inclusive. Year will be set to " + iuLimitYear +".");
                preferences.year.value = iuLimitYear;
        }

//            print(preferences.bgOpacity.value);
    }

    function deleteAll(array) {
        for (item in array)
            delete array[item];

    }

    function fetchData(){
        url.cancel();
        loadingTxt.data = "Retrieving data ...";
        loadingTxt.opacity= (preferences.isMaximized.value=="1" || loadingImg.opacity > 0) ? 255 : 0;
        loadPreferences();
        var theURL;

        var iYear = parseInt(preferences.year.value) + 1;
        // Build URL to fetch data
        if (preferences.displayConferenceStandings.value=="1")
            //theURL= "http://sports.espn.go.com/nba/standings?season=" + iYear;
            theURL = "http://sports.espn.go.com/nba/standings?group=" + preferences.conferenceGroup.value + "&seasontype=2&season=" + iYear;

        else if (preferences.dataSource.value=="0") {//AOL
            if (preferences.year.value== currentSeason)
                theURL="http://aol.nba.com/" + preferences.aolTeam.value+"/schedule/index.html";
            else
                theURL="http://aol.nba.com/" + preferences.aolTeam.value+"/schedule/results_" + preferences.year.value+ ".html";

        }
        else {//ESPN
            if (preferences.year.value== currentSeason)
                theURL="http://sports.espn.go.com/nba/teams/schedule?team=" + preferences.espnTeam.value;
            else
                theURL="http://sports.espn.go.com/nba/teams/schedule?team=" + preferences.espnTeam.value+"&season=" + iYear;

        }
        url.location = theURL;

        url.fetchAsync(fetchDataComplete);

    }

    // Retrieves the schedule information for AOL.
    function fetchDataComplete(myURL){
        //let's only do all this if we got a valid answer

        if (myURL.response == "200") {
            suppressUpdates();
            logo.opacity=parseInt(preferences.logoOpacity.value);

            deleteAll(backgroundImages);
            deleteAll(games);

            var imgSrc = "Resources/images"

            var imageOpacity = preferences.isMaximized.value=="0" ? 0 : parseInt(preferences.bgOpacity.value);
            var gameTextOpacity =  preferences.isMaximized.value=="0" ? 0 : 255;
            var titleOpacity= preferences.isMaximized.value=="0"  ? 0 : 255;
            //var rowSrc = "Resources/images/rows/row" + preferences.backgroundStyle.value + ".png";
            var rowSrc;

            title.font= preferences.titleFont.value;
            title.size= preferences.titleSize.value;
            title.color= preferences.titleColor.value;
            loadingTxt.color= preferences.titleColor.value;

            //print("Title Color: " + preferences.titleColor.value);

            // Code for movable logo

            if (preferences.logoLocation.value=="1") {
                logo.vOffset = 0;
                logo.hOffset = defaultRowHOffset;
                //title hOffset will be set below
             }
            else {
                title.hOffset = defaultRowHOffset;
                if (preferences.logoLocation.value=="2")
                    logo.vOffset = 0;
            }

            title.opacity=titleOpacity;

            var urlData = myURL.result;
//print(urlData);
            var count=0;
            //seems kinda silly to use reg ex when we can just use the "team"

            var myteam = preferences.aolTeam.value;

            var myMonths = convertMonth(parseInt(preferences.month.value));

            var year2 = parseInt(preferences.year.value)+1;
            var sYear2 = "" + year2;

            sYear2 = sYear2.substring(2, 4);
            sYear1 = preferences.year.value.substring(2, 4);

            var regexTitle;
            var tmpDS = preferences.dataSource.value=="0" ? "AOL" : "ESPN";
            if (preferences.displayConferenceStandings.value=="1") {
                var conTitle = preferences.conferenceToShow.value.replace(/ Conference/gim,'');
                title.data = "'" + sYear1 + "-'" + sYear2 +" " +conTitle; //conferences[teamID]
                //title.tooltip = "Double click '" + conTitle + "' to see other conference";
            }
            else {
                /* title.tooltip = "";
                 if (preferences.dataSource.value=="0") //AOL
                    regexTitle= /<title[^<>]*>([.\s\S]*?) Schedule<\/title>/im;
                else  //ESPN
                    regexTitle = /<td class="tablelrg"><strong>([.\s\S]*?) Schedule<\/strong><\/td>/im;

                var mytitle;
                if (titles = regexTitle.exec(urlData))
                    mytitle = titles[1].replace(/ESPN.com: /gi, '');

                title.data = mytitle + " '" + sYear2 + "-'" + sYear1 + " [" + myMonths[2] + "]"; */

                title.data = myteam.substring(0,1).toUpperCase() + myteam.substring(1, myteam.length).toLowerCase() + " '" + sYear1 + "-'" + sYear2 + " Schedule [" + myMonths[0] + "]";
            }
            //this guy defines how much the logo overlaps the schedule ...
            //since the top row is usually the header row, it's fine if it
            //overlaps more than if the logo is on the bottom
            var backgroundOffset;
            var logoOverlap = 0;
            if (preferences.logoLocation.value=="1" || preferences.logoLocation.value=="2") {
                logoOverlap = initialLogoOverlap + logo.height;
                title.vOffset = logo.vOffset+ logoOverlap;
            }
            else {
                logoOverlap = initialLogoOverlap;
                title.vOffset = title.height;
            }

            backgroundOffset = title.vOffset  + 3;

            //showHeaderRow is no longer an option
            //if (preferences.showHeaderRow.value=="1") {

            for (var i=0; i < display.length; i++)
                    widest[i] = 0;

            //maybe use http://aol.nba.com/js/teamSeasons.js?
            //<td width="+75.0" class="gScGHeader"><a name="Oct"></a><b>&nbsp;Oct</b></td>
            if (preferences.displayConferenceStandings.value=="1") {
                customZOrder = fakeRow.zOrder + 1;
                count = fetchConferenceStandings(preferences.conferenceToShow.value, imageOpacity, gameTextOpacity, "Resources/images/row.png",
                                                 "Resources/images/headerRow.png", widest, backgroundOffset,
                                                 urlData);
            }
            else if (preferences.dataSource.value=="0") { //AOL
                var regexSection = new RegExp("<td[^<>]*class=\"gScGHeader\"><a name=\"" + myMonths[0]+"\">[.\\s\\S]*?(" + myMonths[1] + "|</body>)", "im");

                var regexRow = /<TR[^<>]*>([.\s\S]*?)<\/TR>/gim;

                var regexCell = /<TD[^<>]*class="(gSGRowEven|gSGRowOdd|gScGHeader)">([.\s\S]*?)(<\/TD>)/gim;

                var isHeader = false;
                customZOrder = fakeRow.zOrder + 1;
                section = regexSection.exec( urlData ) ;
                //b/c stupid AOL has a completely messed up site- sometimes they have cells not in a freakin'
                //row
                section = "<tr>" + section;

                while (rows = regexRow.exec( section ) ) {
                    isHeader = false;
                    //print("row " + rc +": " + rows[1]);
                    rc++;
                    var cc=0;

                    var day="";
                    var date="";
                    var who="";
                    var time="";
                    var localtv="";
                    var networktv="";
                    var radio="";
                    var pos = -1;
                    var rc=0;

                    myWhile:
                    while (cells = regexCell.exec(rows[1]) ) {
                        var cellData = cells[2];
                        cellData = cleanHTML(cellData);

                        if (cellData!="") {

                            //print(cc + ": " + cellData);
                            if (cells[1]=="gScGHeader")
                                isHeader = true;


                                mySwitch:
                                switch (cc) {
                                    case 0:
                                        date = cellData;
                                        break;
                                    case 1:  //opponent
                                        who=cellData;
                                        if (who.length==0) who=" ";
                                        break;
                                    case 2:  //time
                                        time=cellData;
                                        if (rc==1 && time == "")
                                            time = "TIME";
                                        break;
                                    case 3:  //tv
                                        localtv=cellData;
                                        break;
                                    case 4:  //tv
                                        networktv=cellData;
                                        break;
                                    case 5:  //radio
                                        radio=cellData;
                                        break;
                                    default:
                                } //end switch

                                cc++;
                        } //nothing in cell
                    } //end cells

                    //print(cc);

                    if ( cc>=4 ) {
                        var colorize
                        var font;
                        var fontSize;
                        var textColor;

                        if (isHeader) {
                            colorize =  (preferences.colorizeHeaderRow.value=="1") ? preferences.headerRowColor.value : "";
                            textColor=preferences.headerTextColor.value;

                            font=preferences.headerTextFont.value;
                            fontSize=preferences.headerTextSize.value;

                            rowSrc = "Resources/images/headerRow.png";
                        }
                        else {
                            colorize =  (preferences.colorizeRows.value=="1") ? preferences.rowColor.value : "";
                            var homeGame= who.indexOf('@') > -1 ? false: true;
                            if (homeGame)
                                textColor=preferences.homeTextColor.value;
                            else
                                textColor=preferences.awayTextColor.value;

                            font=preferences.textFont.value;
                            fontSize=preferences.textSize.value;
                            rowSrc = "Resources/images/row.png";
                        }

                        // Draw Background Rows

                        displayCount=0;

                        addBGRow(count, backgroundOffset, colorize, imageOpacity,rowSrc);
                        addTextRow(count, textColor, font, fontSize, gameTextOpacity);

                        //write the day/date

                        if (!isHeader) {
                            var spacePos = date.indexOf(' ');
                            day = date.substring(0, spacePos);
                            date = date.substring(spacePos + 1, date.length);
                            date = preferences.month.value  + '/' + date;
                        }
                        else {
                            day = "DAY";
                            date = "DATE";
                        }

                        if (display[0]=="1")
                            games[count][0].data = day;

                        if (display[1]=="1")
                            games[count][1].data = date;

                        // Write the who
                        who = who.replace(/ Preseason[.\s\S]*?$/gi, ' [Preseason]');
                        games[count][2].data = !isHeader ? who : who.toUpperCase();

                        // Write the time
                        if (display[3]=="1") {
                            if(!isHeader)
                                games[count][3].data = adjustTime(time);
                            else //replace Box Score with Result to make things more consistent w/ ESPN col names
                                games[count][3].data = time.toUpperCase().replace(/\*/gi,'').replace(/BOX SCORE/gi, 'RESULT'); //since we don't want "Time*"
                        }

                        // Write the local tv
                        if (display[4]=="1")
                            games[count][4].data = !isHeader ? localtv : localtv.toUpperCase().replace(/LOCAL TV/gi, 'LOC TV'); //since we don't want the cols too wide

                        // Write the network tv
                        if (display[5]=="1")
                            games[count][5].data = !isHeader ? networktv : networktv.toUpperCase().replace(/NATIONAL TV/gi, 'NAT TV');//since we don't want the cols too wide

                        // Write the radio
                        if (display[6]=="1") {
                            if (!isHeader)
                                games[count][6].data = radio;
                            else {
                                if (radio.length>0)
                                    games[count][6].data =  radio.toUpperCase();
                                else
                                    games[count][6].data =  "RADIO";
                            }
                        }
                        tallest = games[count][2].height;

                        for (var i=0; i < display.length; i++) {
                            if (display[i]=="1") {
                                if (games[count][i].width > widest[i])
                                    widest[i] = games[count][i].width;

                            }//if
                        } //for

                        backgroundImages[count].height  = tallest+padding;

                        for (var i=0; i < display.length; i++){
                            if (games[count][i]!=null)
                                games[count][i].vOffset = backgroundImages[count].vOffset + backgroundImages[count].height - padding/1.5;
                        }
                        backgroundOffset += backgroundImages[count].height;
                        count++;
                    } //good column count (i.e. we want to disply this row)

                }//row regex loop
            } //END OF AOL SECTION
            else { //ESPN
                var headerDate = "";

                var myMonths = convertMonth(parseInt(preferences.month.value));

                if (myMonths[3]!="")
                    regexSection = new RegExp("<tr[^<>]* class=\"?colhead\"?[^<>]*>[\\s]*<td[^<>]*>" + myMonths[2] + "<\\/td>[.\\s\\S]*?" + myMonths[3] + "<\\/td>", "im");
                else
                    regexSection = new RegExp("<tr[^<>]* class=\"?colhead\"?[^<>]*>[\\s]*<td[^<>]*>" + myMonths[2] + "<\\/td>[.\\s\\S]*?<\\/table>", "im");

                regexRow = /<TR[^<>]*class="?(evenrow|oddrow|colhead)"?[^<>]*>([.\s\S]*?)<\/TR>/gim;
                regexCell = /<TD([^<>])*>([.\s\S]*?)(<\/TD>)/gim;

                var rc=0;

                customZOrder = fakeRow.zOrder + 1;
                var section = regexSection.exec( urlData ) ;
                while (rows = regexRow.exec( section ) ) {

                    isHeader = false;

                    rc++;
                    var cc=0;

                    var day="";
                    var date="";
                    var who="";
                    var time="";
                    var pos = -1;
                    var lineOrLocalTV="";
                    var recordOrNationalTV="";
                    var hiPts="";
                    var hiReb="";
                    var hiAsst="";

                    if (rows[1]=="colhead") isHeader = true;

                    //month, opp, res, line (skip), record, hi pts, hi reb, hi asst
                    //month, opp, time,  tv, nat tv
                    //month is day space date

                    myWhile:
                    while (cells = regexCell.exec(rows[2]) ) {
                        var cellData = cleanHTML(cells[2]);
                        //print(cellData);
                        mySwitch:
                        switch (cc) {
                            case 0: //day/date
                                date= cellData;
                                break;
                            case 1:  //opponent
                                who=cellData;
                                if (who.length==0) who = " ";
                                break;
                            case 2:  //time/result
                                time=cellData;
                                break;
                            case 3:  //line (wth is this?) or tv
                                lineOrLocalTV = cellData.replace(/Comcast Sports/gi, 'CSN').replace(/Channel/gi, 'Ch.'); //to prevent cols from being too wide
                            case 4: //record or tv
                                recordOrNationalTV= cellData;
                                break;
                            case 5: //hi pts or the dreaded TICKETS
                                hiPTS= cellData.replace(/Tickets/gi, '');
                                break;
                            case 6: //hi reb
                                hiReb= cellData;
                                break;
                            case 7: //hi asst
                                hiAsst= cellData;
                                break;
                            default:
                        } //end switch

                        cc++;
                    } //end cells

                   if (cc==1) headerDate = time;

                   if ( cc>=4 ) {

                        //if cc = 8 we have a completed game
                        //and we'll need to know this down below
                        var isCompletedGame = cc==8;

                        var colorize
                        var font;
                        var fontSize;
                        var textColor;

                        if (isHeader) {
                            colorize =  (preferences.colorizeHeaderRow.value=="1") ? preferences.headerRowColor.value : "";
                            textColor=preferences.headerTextColor.value;

                            font=preferences.headerTextFont.value;
                            fontSize=preferences.headerTextSize.value;

                            rowSrc = "Resources/images/headerRow.png";
                        }
                        else {
                            colorize =  (preferences.colorizeRows.value=="1") ? preferences.rowColor.value : "";
                            var homeGame= who.indexOf('@') > -1 ? false: true;

                            if (homeGame) {
                                if (who.substring(0, 3)=="at ")
                                    homeGame = false;
                            }

                            if (homeGame)
                                textColor=preferences.homeTextColor.value;
                            else
                                textColor=preferences.awayTextColor.value;

                            font=preferences.textFont.value;
                            fontSize=preferences.textSize.value;
                            rowSrc = "Resources/images/row.png";

                        }

                        // Draw Background Rows

                        displayCount=0;

                        addBGRow(count, backgroundOffset, colorize, imageOpacity,rowSrc);
                        addTextRow(count, textColor, font, fontSize, gameTextOpacity);

                        //write the day/date

                        if (!isHeader) {
                            var spacePos = date.indexOf(' ');
                            day = date.substring(0, spacePos);
                            date = date.substring(spacePos + 1, date.length);
                            date = preferences.month.value  + '/' + date;
                        }
                        else {
                            day = "DAY";
                            date = "DATE";
                        }

                        if (display[0]=="1")
                            games[count][0].data = day;

                        if (display[1]=="1")
                            games[count][1].data = date;

                        // Write the who
                        who = who.replace(/ Preseason[.\s\S]*?$/gi, ' [Preseason]');
                        games[count][2].data = !isHeader ? who : who.toUpperCase();

                        // Write the time
                        if (display[3]=="1") {
                            if(!isHeader)
                                games[count][3].data = adjustTime(time);
                            else
                                games[count][3].data = time.toUpperCase().replace(/\*/gi,'').replace(/ \(ET\)/gi,''); //since we don't want "Time*" or Time (ET)
                        }

                        //now is where stuff gets tricky, because we don't want to print the line col
                        //so basically, from here on out, my carefully chosen variable names are worthless
                        if (isCompletedGame) {
                            lineOrLocalTV = recordOrNationalTV;
                            recordOrNationalTV = hiPTS;
                            hiPts = hiReb;
                            hiReb = hiAsst;

                            //replace REC with W-L to make things more consistent w/ AOL col names
                            //in fact, let's make the HI headers be the AOL headers
                            if (isHeader) {
                                lineOrLocalTV='W-L';
                                recordOrNationalTV = 'HI PTS';
                                hiPts = 'HI REB';
                                hiReb = 'HI ASST'; //altho i think HI ASS would be funny
                            }
                        }
                        else {
                            if (isHeader) {
                                lineOrLocalTV = 'LOC TV';
                                recordOrNationalTV = 'NAT TV';
                            }
                        }

                        // Write the local tv/record
                        if (display[4]=="1" )
                            games[count][4].data = !isHeader ? lineOrLocalTV : lineOrLocalTV.toUpperCase();

                        // Write the nat tv/hiPts
                       if (display[5]=="1")
                           games[count][5].data = !isHeader ? recordOrNationalTV : recordOrNationalTV.toUpperCase();

                        // Write the hi reb
                        if (display[6]=="1")
                            games[count][6].data = !isHeader ? hiPts : hiPts.toUpperCase();


                        // Write the hi asst
                        if (display[7]=="1")
                            games[count][7].data = !isHeader ? hiReb: hiReb.toUpperCase();


                        tallest = games[count][2].height;

                        for (var i=0; i < display.length; i++) {
                            if (display[i]=="1") {
                                if (games[count][i].width > widest[i])
                                    widest[i] = games[count][i].width;

                            }//if
                        } //for

                        backgroundImages[count].height  = tallest+padding;

                        for (var i=0; i < display.length; i++){
                            if (games[count][i]!=null)
                                games[count][i].vOffset = backgroundImages[count].vOffset + backgroundImages[count].height - padding/1.5;
                        }
                        backgroundOffset += backgroundImages[count].height;
                        count++;
                    } //good column count (i.e. we want to disply this row)

                }//row regex loop

            } //espn
            //loop thru and fix the offsets
            //and set the image widths

            for (var i=0; i < count; i++) {

                for (var j=0; j < display.length; j++) {

                    if (display[j]=="1") {

                        var offset = defaultRowHOffset;
                        for (var k=0; k < j; k++) {
                            if (display[k]=="1" && widest[k] >0 )
                                offset += widest[k]+hCellSpacing;
                        } //for k lt j

                        games[i][j].hOffset = padding + offset;

                    } //if
                } //for

                var maxWidth=0;
                var dispCount=0;
                for (var w=0; w < widest.length; w++) {
                    if (display[w] > 0) {
                        dispCount++;
                        maxWidth += widest[w];
                    }
                }

                backgroundImages[i].width = hCellSpacing + maxWidth + ((dispCount-1)*hCellSpacing);
            } //for

            currentArraySize=count;

            var useWidth=0;
            var useHeight = 0;

            if (currentArraySize==0)
                alert("No data returned.  This usually that there are no games for the month chosen.  For example, if it's early in the season, May and June may not have any games scheduled yet. It could also mean that the website has recently changed their layout, or you selected a year or month for which there is no data.");
            else
                count--;

            var rowWidth;
            if (currentArraySize > 0 && backgroundImages[count] != null) {
                var tmpWidth = Math.max(logo.width, title.width);
                useWidth = Math.max(tmpWidth, backgroundImages[count].hOffset + backgroundImages[count].width);
                rowWidth=backgroundImages[count].hOffset + backgroundImages[count].width
                useHeight = backgroundImages[count].vOffset + backgroundImages[count].height + 10;
            }
            else{
                useWidth = logo.width+title.width;
                useHeight = logo.height;
            }

            mainWindow.width = useWidth;

            if (preferences.logoLocation.value=="1")
               title.hOffset =useWidth - title.width;
            else
               title.hOffset =defaultRowHOffset;

            logo.zOrder = customZOrder + 20000;
            title.zOrder = logo.zOrder + 1;
            plusMinus.zOrder = title.zOrder + 1;

            // Code for movable logo
            if (preferences.logoLocation.value=="1" || preferences.logoLocation.value=="2")
                mainWindow.height = useHeight+prev.height;
            else
                mainWindow.height = useHeight + logo.height;

            //"1" and 2s vOffset handled above

            if (preferences.logoLocation.value=="1") {
                setNextPrevLocation(1);

                refresh.hOffset = rowWidth-refresh.width-2;
                loadingTxt.hOffset = refresh.hOffset -loadingTxt.width-2;

            }
            else if (preferences.logoLocation.value=="2") {
                logo.hOffset = mainWindow.width - logo.width-1;
                setNextPrevLocation(1);

                refresh.hOffset = rowWidth-refresh.width-2;
                loadingTxt.hOffset = refresh.hOffset -loadingTxt.width-2;

            }
            else if (preferences.logoLocation.value=="3") {
                logo.vOffset = mainWindow.height-logo.height - logoOverlap;
                logo.hOffset = mainWindow.width - logo.width-1;
                setNextPrevLocation(1);

                refresh.hOffset = next.hOffset + next.width + 5;

                loadingTxt.hOffset = refresh.hOffset + refresh.width+2;

            }
            else if (preferences.logoLocation.value=="4") {
                logo.vOffset = mainWindow.height-logo.height - logoOverlap;
                logo.hOffset = 0;
                setNextPrevLocation(0);

                refresh.hOffset = prev.hOffset - refresh.width - 5;

                loadingTxt.hOffset = refresh.hOffset -loadingTxt.width-2;

            }

            refresh.vOffset = prev.vOffset;
            loadingTxt.vOffset = refresh.vOffset +loadingTxt.height;
            refresh.zOrder=next.zOrder+2;

            plusMinus.vOffset = logo.vOffset + pmVOffset;
            plusMinus.hOffset = logo.hOffset + pmHOffset;

            sizeFakeRow();

            loadingImg.opacity=0;

            loadingTxt.opacity=0;

            logo.tooltip = updateTimestamp() + " [" + tmpDS + "]";

            //must do this, or stuff doesn't update properly on my mac
            //sleep(500);
            resumeUpdates();
    } // ok response
    else {
        alert("Unable to contact website.  The site may be down, or your internet connection may not be on.  If you have recently changed your Preferences, some of those changes may not be applied until you refresh. Please try again later. ");

        loadingTxt.data = "Unable to contact website.  Please try later.";
        loadingImg.height = loadingTxt.height + 10;

        if (loadingImg.opacity > 0) {
            loadingImg.width = loadingTxt.hOffset + loadingTxt.width + loadingTxt.hOffset;
            mainWindow.width = loadingImg.width;
            mainWindow.height = loadingImg.height+logo.height;
            fakeRow.width = mainWindow.width;
            fakeRow.height = mainWindow.height;
            logo.opacity = 255;
            loadingImg.vOffset = logo.vOffset + logo.height;
            loadingTxt.vOffset = loadingImg.vOffset + loadingTxt.height+2;
         }
    }

}

function setNextPrevLocation(lowerLeft) {
    //should create an init function to handle this ... there's no need to reset
    //it every time
    loadingTxt.size = 8;

    var vo;
    if (backgroundImages != null && currentArraySize>0)
        vo = backgroundImages[currentArraySize-1].vOffset + backgroundImages[currentArraySize-1].height;
    else
        vo= mainWindow.height - prev.height;

    next.vOffset = vo;
    prev.vOffset = vo;

    //if the widget is really skinny and the logo is on the bottom,
    //we want these buttons to be on top
    next.zOrder=logo.zOrder+1;
    prev.zOrder=next.zOrder;

    if (lowerLeft==1) {
        prev.hOffset = defaultRowHOffset+1;
        next.hOffset = prev.hOffset + prev.width;

    }
    else  { //lower right
        prev.hOffset = mainWindow.width-prev.width-next.width-2;
        next.hOffset = prev.hOffset + prev.width;
    }
    updateNow();
}

function showOrHideMe(reloadData){

    //refresh if maximized and the user said to do that
    if (reloadData || (preferences.isMaximized.value=="1" && preferences.refreshOnMaximize.value=="1")){
        // force to redraw before fetching data
        //this might be inefficient, but i've been having serious issues on my mac
        //that were no present in windows
        updateNow();
        fetchData();
    }

    if (preferences.isMaximized.value=="0")
        plusMinus.src = "Resources/images/plus.png"
    else
        plusMinus.src = "Resources/images/minus.png"

    //generally speaking, this guy should always have an opacity of 0, unless
    //we encountered an error during the initial "fetchData"
    if (loadingImg.opacity ==0) {
        var imageOpacity = preferences.isMaximized.value=="0" ? 0 : parseInt(preferences.bgOpacity.value);
        var gameTextOpacity =  preferences.isMaximized.value=="0" ? 0 : 255;
        var prevNextOpacity= preferences.isMaximized.value=="0"  ? 0 : 255;
        var refreshOpacity= preferences.isMaximized.value=="0" ? 0 : 255;

        var titleOpacity= preferences.isMaximized.value=="0" ? 0 : 255;

        for (var i = 0; i< backgroundImages.length; i++) {
            if (backgroundImages[i] != null) {
                //for (var imgCount=0; imgCount < 3; imgCount++)
                   // backgroundImages[i][imgCount].opacity = imageOpacity;
              backgroundImages[i].opacity = imageOpacity;
            }
        }

        sizeFakeRow();

        for (var i=0 ; i < games.length; i++) {
            if (games[i] != null ) {
                for (var j=0; j < games[i].length; j++) {
                   if (games[i][j] != null)
                        games[i][j].opacity=gameTextOpacity;
                }
            }
        }

        title.opacity=titleOpacity;
        prev.opacity=prevNextOpacity;
        next.opacity = prevNextOpacity;
        refresh.opacity = refreshOpacity;
    }
}

function sizeFakeRow() {
    if (preferences.isMaximized.value=="0" ) {
        var trueWidth = logo.width+1; //for plus/minus
        fakeRow.hOffset = logo.hOffset;
        fakeRow.vOffset = logo.vOffset;
        fakeRow.width = trueWidth;
        fakeRow.height = logo.height+3;//give it a little buffer below

    }
    else {
        fakeRow.hOffset = 0;
        fakeRow.vOffset = 0;
        fakeRow.width = mainWindow.width;
        fakeRow.height = mainWindow.height;
    }
}
